@@ -60,15 +60,11 @@ class InvalidCall(Exception):
 
 class DynamicBridge(object):
     def __init__(self):
-        paths = [vdsmapi.find_schema()]
         api_strict_mode = config.getboolean('devel', 'api_strict_mode')
-        if _glusterEnabled:
-            paths.append(vdsmapi.find_schema('vdsm-api-gluster'))
-        self._schema = vdsmapi.Schema(paths, api_strict_mode)
+        self._schema = vdsmapi.Schema.vdsm_api(api_strict_mode,
+                                               with_gluster=_glusterEnabled)
 
-        self._event_schema = vdsmapi.Schema(
-            [vdsmapi.find_schema('vdsm-events')],
-            api_strict_mode)
+        self._event_schema = vdsmapi.Schema.vdsm_events(api_strict_mode)
 
         self._threadLocal = threading.local()
         self.log = logging.getLogger('DynamicBridge')
