@@ -241,7 +241,8 @@ class Drive(core.Base):
         self.truesize = int(kwargs.get('truesize', '0'))
         self.apparentsize = int(kwargs.get('apparentsize', '0'))
         self.name = drivename.make(self.iface, self.index)
-        self.cache = config.get('vars', 'qemu_drive_cache')
+        if not hasattr(self, 'cache'):
+            self._set_cache()
         self.discard = kwargs.get('discard', False)
 
         # Engine can send 'true' and 'false' as strings
@@ -253,9 +254,27 @@ class Drive(core.Base):
         # Used for chunked drives or drives replicating to chunked replica.
         self.blockinfo = None
 
-        self._customize()
         self._setExtSharedState()
 
+    def _set_cache(self):
+        # default
+        self.cache = config.get('vars', 'qemu_drive_cache')
+
+        # do we need overrides?
+        if self.transientDisk:
+            # Force the cache to be writethrough, which is qemu's default.
+            # This is done to ensure that we don't ever use cache=none for
+            # transient disks, since we create them in /var/run/vdsm which
+            # may end up on tmpfs and don't support O_DIRECT, and qemu uses
+            # O_DIRECT when cache=none and hence hotplug might fail with
+            # error that one can take eternity to debug the reason behind it!
+            self.cache = "writethrough"
+        elif self.iface == 'virtio':
+            try:
+                self.cache = self.vm_custom['viodiskcache']
+            except KeyError:
+                pass  # Ignore if custom disk cache is missing
+
     def _setExtSharedState(self):
         # We cannot use tobool here as shared can take several values
         # (e.g. none, exclusive) that would be all mapped to False.
@@ -514,21 +533,6 @@ class Drive(core.Base):
         # Using getattr to handle legacy and removable drives.
         return getattr(self, 'shared', None) == DRIVE_SHARED_TYPE.TRANSIENT
 
-    def _customize(self):
-        if self.transientDisk:
-            # Force the cache to be writethrough, which is qemu's default.
-            # This is done to ensure that we don't ever use cache=none for
-            # transient disks, since we create them in /var/run/vdsm which
-            # may end up on tmpfs and don't support O_DIRECT, and qemu uses
-            # O_DIRECT when cache=none and hence hotplug might fail with
-            # error that one can take eternity to debug the reason behind it!
-            self.cache = "writethrough"
-        elif self.iface == 'virtio':
-            try:
-                self.cache = self.vm_custom['viodiskcache']
-            except KeyError:
-                pass  # Ignore if custom disk cache is missing
-
     def getLeasesXML(self):
         """
         Get lease device elements for drive leases.
@@ -568,6 +572,7 @@ class Drive(core.Base):
           <source file='/path/to/image'/>
           <target dev='hda' bus='ide'/>
           <serial>54-a672-23e5b495a9ea</serial>
+          [<alias name="ua-2b418ef2-91d8-4479-88b1-98461192a54e/>]
         </disk>
         """
         self._validate()
@@ -600,6 +605,9 @@ class Drive(core.Base):
         if self.iotune:
             diskelem.appendChild(self._getIotuneXML())
 
+        if hasattr(self, 'alias'):
+            diskelem.appendChildWithArgs('alias', name=self.alias)
+
         return diskelem
 
     def get_extra_xmls(self):
