@@ -53,6 +53,14 @@ class FakeDomainManifest(object):
     def getMetaParam(self, key):
         pass
 
+    @recorded
+    def supportsSparseness(self):
+        pass
+
+    @recorded
+    def recommends_unordered_writes(self, format):
+        pass
+
     @recorded
     def qcow2_compat(self):
         pass
@@ -705,6 +713,8 @@ class DomainTestMixin(object):
         ['getMDPath', 0],
         ['getMetaParam', 1],
         ['getVersion', 0],
+        ['supportsSparseness', 0],
+        ['recommends_unordered_writes', 1],
         ['qcow2_compat', 0],
         ['getMetadata', 0],
         ['getFormat', 0],
